<?php

/**
 * Representa el la estructura de las haciendas
 * almacenadas en la base de datos
 */
require 'Database.php';

class Hacienda
{
    function __construct()
    {
    }

    /**
     * Retorna en la fila especificada de la tabla 'haciendas'
     *
     * @param $idHacienda Identificador del registro
     * @return array Datos del registro
     */
    public static function getAll()
    {
        $consulta = "SELECT * FROM haciendas";
        try {
            // Preparar sentencia
            $comando = Database::getInstance()->getDb()->prepare($consulta);
            // Ejecutar sentencia preparada
            $comando->execute();

            return $comando->fetchAll(PDO::FETCH_ASSOC);

        } catch (PDOException $e) {
            return false;
        }
    }

    /**
     * Obtiene los campos de una hacienda con un identificador
     * determinado
     *
     * @param $idHacienda Identificador de la hacienda
     * @return mixed
     */
    public static function getById($idHacienda)
    {
        // Consulta de la hacienda
        $consulta = "SELECT id,
                            nombre,
                             descripcion,
                             antiguedad,
                             historia,
                             dimension,
                             longitud,
                             latitud
                             FROM haciendas
                             WHERE id = ?";

        try {
            // Preparar sentencia
            $comando = Database::getInstance()->getDb()->prepare($consulta);
            // Ejecutar sentencia preparada
            $comando->execute(array($idHacienda));
            // Capturar primera fila del resultado
            $row = $comando->fetch(PDO::FETCH_ASSOC);
            return $row;

        } catch (PDOException $e) {
            // Aquí puedes clasificar el error dependiendo de la excepción
            // para presentarlo en la respuesta Json
            return -1;
        }
    }

    /**
     * Actualiza un registro de la bases de datos basado
     * en los nuevos valores relacionados con un identificador
     *
     * @param $idHacienda      identificador
     * @param $nombre      nuevo nombre
     * @param $descripcion nueva descripcion
     * @param $antiguedad    nueva antiguedad
     * @param $historia   nueva historia
     * @param $dimension   nueva dimension
     * @param $longitud   nueva longitud
     * @param $latitud   nueva latitud
     */
    public static function update(
        $idHacienda,
        $nombre,
        $descripcion,
        $antiguedad,
        $historia,
        $dimension,
        $longitud,
        $latitud
    )
    {
        // Creando consulta UPDATE
        $consulta = "UPDATE haciendas" .
            " SET nombre=?, descripcion=?, antiguedad=?, historia=?, dimension=?, longitud=?, latitud=? " .
            "WHERE idHacienda=?";

        // Preparar la sentencia
        $cmd = Database::getInstance()->getDb()->prepare($consulta);

        // Relacionar y ejecutar la sentencia
        $cmd->execute(array($nombre, $descripcion, $antiguedad, $historia, $dimension, $longitud, $latitud ,$idHacienda));

        return $cmd;
    }

    /**
     * Insertar una nueva hacienda
     *
     * @param $nombre      nuevo nombre
     * @param $descripcion nueva descripcion
     * @param $antiguedad    nueva antiguedad
     * @param $historia   nueva historia
     * @param $dimension   nueva dimension
     * @param $longitud   nueva longitud
     * @param $latitud   nueva latitud
     * @return PDOStatement
     */
    public static function insert(
        $nombre,
        $descripcion,
        $antiguedad,
        $historia,
        $dimension,
        $longitud,
        $latitud
    )
    {
        // Sentencia INSERT
        $comando = "INSERT INTO haciendas ( " .
            "nombre," .
            " descripcion," .
            " antiguedad," .
            " historia," .
            " dimension)" .
            "longitud".
            "latitud".
            " VALUES( ?,?,?,?,?,?,?)";

        // Preparar la sentencia
        $sentencia = Database::getInstance()->getDb()->prepare($comando);

        return $sentencia->execute(
            array(
                $nombre,
                $descripcion,
                $antiguedad,
                $historia,
                $dimension,
                $longitud,
                $latitud
            )
        );

    }

    /**
     * Eliminar el registro con el identificador especificado
     *
     * @param $idHacienda identificador de la hacienda
     * @return bool Respuesta de la eliminación
     */
    public static function delete($idHacienda)
    {
        // Sentencia DELETE
        $comando = "DELETE FROM haciendas WHERE id=?";

        // Preparar la sentencia
        $sentencia = Database::getInstance()->getDb()->prepare($comando);

        return $sentencia->execute(array($idHacienda));
    }
}

?>